@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::InMilitaryRange;
-$BalanceOfPower::Commands::InMilitaryRange::VERSION = '0.120000';
+$BalanceOfPower::Commands::InMilitaryRange::VERSION = '0.130000';
 use Moo;
 
 extends 'BalanceOfPower::Commands::TargetNation';
@@ -12,9 +12,9 @@ has crisis_needed => (
 sub get_available_targets
 {
     my $self = shift;
-    my $player = $self->world->player_nation;
+    my $player = $self->actor;
     my @out = ();
-    for(@{$self->world->nation_names})
+    for($self->SUPER::get_available_targets())
     {
         my $n = $_;
         my $push = 0;
