@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::TargetFriends;
-$BalanceOfPower::Commands::TargetFriends::VERSION = '0.120000';
+$BalanceOfPower::Commands::TargetFriends::VERSION = '0.130000';
 use Moo;
 
 extends 'BalanceOfPower::Commands::TargetNation';
@@ -7,7 +7,7 @@ extends 'BalanceOfPower::Commands::TargetNation';
 sub get_available_targets
 {
     my $self = shift;
-    return $self->world->get_friends($self->world->player_nation);    
+    return $self->world->get_friends($self->actor);    
 }
 
 1;
