@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::RelPack;
-$BalanceOfPower::Relations::RelPack::VERSION = '0.120000';
+$BalanceOfPower::Relations::RelPack::VERSION = '0.130000';
 use strict;
 use v5.10;
 
@@ -194,6 +194,35 @@ sub first_link_for_node
     }
     return undef;
 }
+sub first_link_for_node1
+{
+    my $self = shift;
+    my $node = shift;
+    my @links = $self->links_for_node1($node);
+    if(@links)
+    {
+        return $links[0]
+    }
+    else
+    {
+        return undef;
+    }
+}
+sub first_link_for_node2
+{
+    my $self = shift;
+    my $node = shift;
+    my @links = $self->links_for_node2($node);
+    if(@links)
+    {
+        return $links[0]
+    }
+    else
+    {
+        return undef;
+    }
+}
+
 sub link_destinations_for_node
 {
     my $self = shift;
