@@ -1,10 +1,11 @@
 package BalanceOfPower::Role::Analyst;
-$BalanceOfPower::Role::Analyst::VERSION = '0.120000';
+$BalanceOfPower::Role::Analyst::VERSION = '0.130000';
 use strict;
 use v5.10;
 use Moo::Role;
 use Term::ANSIColor;
-use BalanceOfPower::Utils qw( prev_turn as_title as_subtitle );
+use BalanceOfPower::Constants ':all';
+use BalanceOfPower::Utils qw( prev_turn as_title as_title as_subtitle );
 
 requires 'diplomacy_exists';
 requires 'get_borders';
@@ -99,6 +100,12 @@ sub print_nation_actual_situation
         $out .= sprintf "%-35s %-35s", $crisis_text, $war_text;
         $out .="\n";
     }
+    $out .= "\n";
+    if($self->player_nation ne $nation)
+    {
+        $out .= "Relations with player: " . $self->get_diplomacy_relation($self->player_nation, $nation)->print() . "\n";
+        $out .= "\n";
+    }
     return $out;
 }
 
@@ -115,21 +122,18 @@ sub print_borders_analysis
         my $rel = $self->diplomacy_exists($nation, $b);
         $out .= "  Relations: " . $rel->print_status() . " " . 
                                   $rel->print_crisis_bar() . "\n";
-        my @supps = $self->supported($b);
-        if(@supps)
+        my $supps = $self->supported($b);
+        if($supps)
         {
             $out .= as_subtitle("  Military support in the country:\n");
-            foreach my $ms (@supps)
+            my $supporter = $supps->start($b);
+            my $sup_rel = $self->diplomacy_exists($nation, $supporter);
+            $out .= "    $supporter (" . $sup_rel->print_status();
+            if($sup_rel->is_crisis())
             {
-                my $supporter = $ms->start($b);
-                my $sup_rel = $self->diplomacy_exists($nation, $supporter);
-                $out .= "    $supporter (" . $sup_rel->print_status();
-                if($sup_rel->is_crisis())
-                {
-                    $out .= " " . $sup_rel->print_crisis_bar;
-                } 
-                $out .= ")\n";
-            }
+                $out .= " " . $sup_rel->print_crisis_bar;
+            } 
+            $out .= ")\n";
         }
     }
     return $out;
@@ -156,10 +160,10 @@ sub print_near_analysis
                 foreach my $fb (@foreign_borders)
                 {
                     my $other_n = $fb->destination($b);
-                    my @sups = $self->supported($other_n);
-                    for(@sups)
+                    my $sups = $self->supported($other_n);
+                    for($sups)
                     {
-                        if($_->start($other_n) eq $nation)
+                        if($sups->start($other_n) eq $nation)
                         {
                             $out .= "    Military support from: $other_n\n";   
                         }
@@ -175,4 +179,63 @@ sub print_near_analysis
     return $out;
 }
 
+sub print_hotspots
+{
+    my $self = shift;
+    my $out = "";
+    my @crises = $self->get_all_crises();
+    $out .= as_title("CRISES") . "\n";
+    for(@crises)
+    {
+        my $c = $_;
+        if(! $self->war_exists($c->node1, $c->node2))
+        {
+            $out .= as_subtitle($c->print_crisis()) . "\n";
+            $out .= "    " . $self->get_diplomacy_relation($self->player_nation, $c->node1)->print() . "\n" if($self->player_nation ne $c->node1);
+            $out .= "    " . $self->get_diplomacy_relation($self->player_nation, $c->node2)->print(). "\n" if($self->player_nation ne $c->node2);
+            $out .= "\n";
+        }
+    }
+    $out .= "\n";
+    $out .= as_title("WARS") . "\n";
+    my @wars = $self->wars->all();
+    for(@wars)
+    {
+        my $w = $_;
+        $out .= $w->print() . "\n";
+        $out .= "    " . $self->get_diplomacy_relation($self->player_nation, $w->node1)->print() . "\n" if($self->player_nation ne $w->node1);
+        $out .= "    " . $self->get_diplomacy_relation($self->player_nation, $w->node2)->print(). "\n" if($self->player_nation ne $w->node2);
+        $out .= "\n";
+    }
+    $out .= "\n";
+    $out .= as_title("CIVIL WARS") . "\n";
+    foreach my $n (@{$self->nation_names})
+    {
+        if($self->at_civil_war($n))
+        {
+            $out .= "$n is fighting civil war\n";
+            $out .= "    " . $self->get_diplomacy_relation($self->player_nation, $n)->print() . "\n" if($self->player_nation ne $n);
+        }
+    }
+    return $out;
+}
+
+sub print_civil_war_report
+{
+    my $self = shift;
+    my $nation = shift;
+    if (! $self->at_civil_war($nation))
+    {
+        return "$nation is not fightinh civil war";
+    }
+    my $out = "";
+    my $nation_obj = $self->get_nation($nation);
+    $out .= "Rebel provinces: " . $nation_obj->rebel_provinces . "/" . PRODUCTION_UNITS->[$nation_obj->size] . "\n";
+    $out .= "Army: " . $nation_obj->army . "\n";
+    my $sup = $self->supported($nation);
+    my $rebsup = $self->rebel_supported($nation);
+    $out .= "Support: " . $sup->print . "\n" if($sup);
+    $out .= "Rebel support: " . $rebsup->print . "\n" if ($rebsup);
+    return $out;
+}
 1;
