@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Diplomat;
-$BalanceOfPower::Role::Diplomat::VERSION = '0.120000';
+$BalanceOfPower::Role::Diplomat::VERSION = '0.130000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -118,20 +118,23 @@ sub get_diplomacy_relation
     my $real_node1 = $self->get_real_node($node1);
     my $real_node2 = $self->get_real_node($node2);
     my $factor;
+    my $crisis_level;
     if($real_node1 eq $real_node2) 
     {
         $factor = 100;
+        $crisis_level = 0;
     }
     elsif($self->exists_alliance($real_node1, $real_node2))
     {
         $factor = ALLIANCE_FRIENDSHIP_FACTOR;
+        $crisis_level = 0;
     }
     else
     {
         my $r = $self->diplomacy_exists($real_node1, $real_node2);
+        $crisis_level = $self->diplomacy_exists($node1, $node2)->crisis_level();
         $factor = $r->factor;
     }
-    my $crisis_level = $self->diplomacy_exists($node1, $node2)->crisis_level();
     return BalanceOfPower::Relations::Friendship->new(node1 => $node1, node2 => $node2, factor => $factor, crisis_level => $crisis_level);
 }
 
@@ -139,7 +142,20 @@ sub get_diplomacy_relation
 sub get_hates
 {
     my $self = shift;
-    return $self->diplomatic_relations->query( sub { my $rel = shift; return $rel->status eq 'HATE' });
+    my $nation = shift;
+    my @hates = $self->diplomatic_relations->query( sub { my $rel = shift; return $rel->status eq 'HATE' });
+    my @out = ();
+    foreach my $r (@hates)
+    {
+        if(($nation && $r->has_node($nation)) || (! $nation))
+        {
+            if(! $self->is_under_influence($r->node1) && ! $self->is_under_influence($r->node2))
+            {
+                push @out, $r;
+            }
+        }
+    }
+    return @out;
 }
 sub get_nations_with_status
 {
@@ -255,9 +271,9 @@ sub add_crisis
     my $nation1 = shift;
     my $nation2 = shift;
     my $rel = $self->diplomacy_exists($nation1, $nation2);
-    if($rel->crisis_level == 0)
+    if($rel->get_crisis_level == 0)
     {
-        $rel->crisis_level(1);
+        $rel->escalate_crisis();
     }
 }
 sub delete_crisis
@@ -279,7 +295,7 @@ sub crisis_exists
         say "ERROR: $nation1 <-> $nation2";
         return undef;
     }
-    if($rel->crisis_level > 0)
+    if($rel->get_crisis_level > 0)
     {
         return $rel;
     }
@@ -293,7 +309,7 @@ sub get_crises
     my $self = shift;
     my $nation = shift;
     my @crises = $self->get_diplomatic_relations($nation);
-    @crises = grep { $_->crisis_level > 0 } @crises;
+    @crises = grep { $_->get_crisis_level > 0 } @crises;
     return @crises;
 }
 sub get_all_crises
