@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.120000';
+$BalanceOfPower::World::VERSION = '0.130000';
 use strict;
 use v5.10;
 
@@ -116,6 +116,11 @@ sub check_nation_name
     my $name = shift;
     return grep {$_ eq $name} @{$self->nation_names};
 }
+sub get_prev_year
+{
+    my $self = shift;
+    return prev_turn($self->current_year);
+}
 
 sub load_nations_data
 {
@@ -142,7 +147,8 @@ sub load_nations_data
             }
             $nations_data{$name} = { area => $area,
                                      size => $size,
-                                     government => $government }
+                                     government => $government ,
+                                   }
 
         }
         else
@@ -188,14 +194,19 @@ sub init_random
         say "  export quote: $export_quote" if ! $self->silent;
         my $government_strength = $self->random10(MIN_GOVERNMENT_STRENGTH, MAX_GOVERNMENT_STRENGTH, "Government strenght $n");
         say "  government strength: $government_strength" if ! $self->silent;
+
+        my $executive = BalanceOfPower::Executive->new( actor => $n );
+        $executive->init($self);
         push @{$self->nations}, BalanceOfPower::Nation->new( 
             name => $n, 
+            executive => $executive,
             area => $nations_data{$n}->{area}, 
             size => $nations_data{$n}->{size},
             government => $nations_data{$n}->{government},
             export_quote => $export_quote, 
             government_strength => $government_strength,
-            log_name => $self->log_name);
+            log_name => $self->log_name,
+            log_on_stdout => $self->log_on_stdout);
     }
     $self->nation_names(\@nation_names);
     $self->load_borders($bordersfile);
@@ -516,6 +527,25 @@ sub execute_decisions
             my $nation2 = $self->get_nation($3);
             $self->stipulate_treaty($nation1, $nation2, $2);
         }
+        elsif($d =~ /^(.*): ECONOMIC AID FOR (.*)$/)
+        {
+            my $nation1 = $self->get_nation($1);
+            my $nation2 = $self->get_nation($2);
+            $self->economic_aid($nation1, $nation2);
+        }
+        elsif($d =~ /^(.*): REBEL MILITARY SUPPORT (.*)$/)
+        {
+            my $nation1 = $self->get_nation($1);
+            my $nation2 = $self->get_nation($2);
+            if($self->rebel_supported($nation2->name))
+            {
+                $self->broadcast_event("REBEL SUPPORT IN " . $nation2->name . " IMPOSSIBLE FOR " . $nation1->name, $nation1->name, $nation2->name);
+            }
+            else
+            {
+                $self->start_rebel_military_support($nation1, $nation2);
+            }
+        }
     }
     $self->manage_route_adding(@route_adders);
 }
@@ -628,6 +658,17 @@ sub economy
         }
     }
 }
+sub economic_aid
+{
+    my $self = shift;
+    my $nation1 = shift;
+    my $nation2 = shift;
+    $nation1->subtract_production('export', ECONOMIC_AID_COST);
+    $nation2->receive_aid($nation1->name);
+    $self->broadcast_event("ECONOMIC AID FROM " . $nation1->name . " TO " . $nation2->name, $nation1->name, $nation2->name);
+    $self->change_diplomacy($nation1->name, $nation2->name, ECONOMIC_AID_DIPLOMACY_FACTOR);
+
+}
 
 # ECONOMY END #############################################################
 
@@ -652,8 +693,13 @@ sub internal_conflict
         my $winner = $n->fight_civil_war($self);
         if($winner && $winner eq 'rebels')
         {
+            $n->win_civil_war('rebels', $self);
             $n->new_government($self);
         }
+        elsif($winner && $winner eq 'government')
+        {
+            $n->win_civil_war('government', $self);
+        }
         
         $self->set_statistics_value($n, 'internal disorder', $n->internal_disorder);
     }
@@ -672,6 +718,15 @@ sub aid_insurgents
     }
 }
 
+sub at_civil_war
+{
+    my $self = shift;
+    my $n = shift;
+    my $nation = $self->get_nation($n);
+    return $nation->internal_disorder_status eq 'Civil war';
+}
+
+
 # INTERNAL DISORDER END ######################################################
 
 # WAR ######################################################################
@@ -784,7 +839,7 @@ sub build_commands
 {
     my $self = shift;
     my $commands = BalanceOfPower::Commands->new( world => $self, log_name => 'bop-commands.log', log_active => $self->log_active );
-    $commands->init();
+    $commands->init($self);
     return $commands;
 }
 
